@@ -13,5 +13,5 @@
    You should have received a copy of the GNU General Public License
    along with Pyxgram.  If not, see <http://www.gnu.org/licenses/>. """
 
-from bot import Basebot,Logger
+from pyxgram.bot import Basebot,Logger
 BaseBot=Basebot
