@@ -13,8 +13,9 @@
    You should have received a copy of the GNU General Public License
    along with Pyxgram.  If not, see <http://www.gnu.org/licenses/>. """
 
+#Pls send the issues to https://github.com/borisd93/pyxgram/issues/
+
 import time
-import random
 import os
 from functools import partial
 import telegram
@@ -71,7 +72,7 @@ class Basebot:
             self.admin_id=include.admin_id
             self.separator=include.separator
         else:
-            self.admin_id=None
+            self.admin_id=[]
             self.separator='-'
     def error_handler(self,update: telegram.Update,context: telegram.ext.CallbackContext,function):
         """Its a error hancler for all the comands"""
@@ -98,11 +99,12 @@ class Basebot:
             self.log.info('Added a new command')
     def admin_pass(self,update:telegram.Update,context:telegram.ext.CallbackContext,function):
         """This is a minimal subfunction of admin_command decorator"""
-        if update.message.chat_id==self.admin_id:
-            function(update,context)
-        else:
-            if self.logging:
-                self.log.info('A person trying to access to a admin function')
+        for aid in self.admin_id:
+            if update.message.chat_id==aid:
+                function(update,context)
+                break
+            else:
+                pass
     def admin_command(self,function):
         """The admin_command function uses the admin_id from the include.py file
         you can set this with <class>.admin_id=id replacing id with our id."""
@@ -120,7 +122,7 @@ class Basebot:
     def typing(self,update,context):
         """Send's the typing chat action"""
         context.bot.send_chat_action(
-            chat_id=update.message.chat_id, 
+            chat_id=update.message.chat_id,
             action=telegram.ChatAction.TYPING
         )
     def start(self):
@@ -134,20 +136,20 @@ class Basebot:
             if self.logging:
                 self.log.error('Network Error')
                 self.log.error(str(error))
-    def reply(self,text,update):
+    def reply_text(self,text,update):
         """Reply a message with a text.
         This is a shorcut for the
-        update.message..reply_text
+        update.message.reply_text
         function"""
         update.message.reply_text(text)
-    def send_text(self,text,update,context,chat_id=None):
+    def send_text(self,text,update,context,chat_id=None,reply_markup=None):
         """Send a message with a text
         This i a shorcut for the
         bot.send_message or
         context.bot.send_message"""
         if chat_id is None:
             chat_id=update.message.chat_id
-        context.bot.send_message(chat_id,text)
+        context.bot.send_message(chat_id,text,reply_markup)
     def setup_jqe(self):
         """Setup's the Jobqueue"""
         if self._jobqueue is None:
@@ -162,19 +164,58 @@ class Basebot:
             self.log.error('Jobqueue not initiated')
         else:
             self._jobqueue.run_repeating(function,date)
+    # BETA Maybe dont work ↓
+    def jqe_run_once(self,function,date):
+        """Its a shorcut for the Jobqueue of telegram module
+        function - This argument need to be a function
+        date - The time in seconds or datetime.datetime"""
+        if self._jobqueue is None:
+            self.log.error('Jobqueue not initiated')
+        else:
+            self._jobqueue.run_once(function,date)
+    # BETA Maybe dont work ↑
     def jqe_kill(self):
+        """Kills the JQE"""
         if self._jobqueue is None:
             self.log.error('Jobqueue not initiated')
         else:
             self._jobqueue.stop()
     def jqe_start(self):
+        """Starts a killed JQE"""
         if self._jobqueue is None:
             self.log.error('Jobqueue not initiated')
         else:
             self._jobqueue.start()
+    def commandFilter(self,function):
+        """A filter for commands"""
+        self.dispatcher.add_handler(telegram.ext.MessageHandler(telegram.ext.Filters.command,function))
+        self.log.info('Added a Text Filter Handler')
     def textFilter(self,function):
+        """A filter for text"""
         self.dispatcher.add_handler(telegram.ext.MessageHandler(telegram.ext.Filters.text,function))
         self.log.info('Added a Text Filter Handler')
     def documentFilter(self,function):
+        """A filter for documents"""
         self.dispatcher.add_handler(telegram.ext.MessageHandler(telegram.ext.Filters.document,function))
-        self.log.info('Added a Document Filter Handler')
\ No newline at end of file
+        self.log.info('Added a Document Filter Handler')
+    # BETA Maybe dont work ↓
+    def send_with_buttons(self,text,callback,buttons,update,context,chat_id=None):
+        """A function for send the buttons markup, not the buttons menu.
+        An example,
+        self.send_with_buttons(
+            'hello',mycallbackfunction,
+            [
+                [telegram.InlineKeyboardButton("Here",callback_data=1),telegram.InlineKeyboardButton("Here",callback_data=1)]
+            ],"",
+            context,chat_id=update.message.chat_id
+        )"""
+        try:
+            if chat_id is None:
+                chat_id=update.message.chat_id
+            markup=telegram.InlineKeyboardMarkup(buttons)
+            self.send_text(text,update,context,reply_markup=markup)
+            self.dispatcher.add_handler(telegram.ext.CallbackQueryHandler(callback))
+        except Exception as e:
+            print('Thanks for testing, an Error as ocurred please send to my email the full log edkz@nogafam.me')
+            self.log.error('Unknow error at lines 196:212, please see the full the log. '+str(e))
+    # BETA Maybe dont work ↑
